package com.muyu.data.source.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.data.source.domain.AssetAuthInfo;
import com.muyu.data.source.domain.req.AssetAuthInfoQueryReq;
import com.muyu.data.source.service.AssetAuthInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 资产授权Controller层
 *
 * @ClassName AssetAuthInfoController
 * @Author AnNan.Wang
 * @Date 2024/5/5 15:38
 */

@Api(tags = "资产授权")
@RestController
@RequestMapping("/auth")
public class AssetAuthInfoController extends BaseController {
    @Autowired
    private AssetAuthInfoService assetAuthInfoService;

    @ApiOperation("获取资产授权列表")
    @RequiresPermissions("source:auth:list")
    @GetMapping("/list")
    public Result<TableDataInfo<AssetAuthInfo>> list(AssetAuthInfoQueryReq assetAuthInfoQueryReq) {
        startPage();
        List<AssetAuthInfo> list = assetAuthInfoService.list(AssetAuthInfo.queryBuild(assetAuthInfoQueryReq));
        return getDataTable(list);
    }

    @RequiresPermissions("source:auth:add")
    @Log(title = "资产授权", businessType = BusinessType.DELETE)
    @RequestMapping
    @ApiOperation("新增资产授权")
    public Result<String> add(@RequestBody AssetAuthInfoQueryReq assetAuthInfoQueryReq){
        return toAjax(assetAuthInfoService.save(AssetAuthInfo.saveBuild(assetAuthInfoQueryReq, SecurityUtils::getUsername)));
    }

    @RequiresPermissions("source:auth:remove")
    @Log(title = "资产授权", businessType = BusinessType.DELETE)
    @PostMapping("/remove")
    @ApiOperation("删除资产授权")
    public Result<String> remove(@RequestBody AssetAuthInfoQueryReq  assetAuthInfoQueryReq){
        return assetAuthInfoService.removeList(assetAuthInfoQueryReq);
    }
}
