package com.muyu.data.source.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.exception.ServiceException;
import com.muyu.data.source.domain.AssetAuthInfo;
import com.muyu.data.source.domain.req.AssetAuthInfoQueryReq;
import com.muyu.data.source.mapper.AssetAuthInfoMapper;
import com.muyu.data.source.service.AssetAuthInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Objects;

/**
 * AssetAuthInfo 资产授权Impl实现层
 *
 * @ClassName AssetAuthInfoServiceImpl
 * @Author AnNan.Wang
 * @Date 2024/5/5 18:29
 */

@Service
public class AssetAuthInfoServiceImpl extends ServiceImpl<AssetAuthInfoMapper, AssetAuthInfo>
        implements AssetAuthInfoService{
    @Autowired
    private AssetAuthInfoMapper assetAuthInfoMapper;

    @Override
    public List<AssetAuthInfo> list(AssetAuthInfo assetAuthInfo) {
        if (Objects.isNull(assetAuthInfo.getIdType())){
            throw new ServiceException("id类型不能为空");
        }
        if (Objects.isNull(assetAuthInfo.getAuthType())){
            throw new ServiceException("授权类型不能为空");
        }

        return list(new LambdaQueryWrapper<AssetAuthInfo>()
                .eq(AssetAuthInfo::getIdType, assetAuthInfo.getIdType())
                .eq(AssetAuthInfo::getAuthType, assetAuthInfo.getAuthType()));
    }

    @Override
    public Result<String> removeList(AssetAuthInfoQueryReq assetAuthInfoQueryReq) {
        int delete = assetAuthInfoMapper.delete(
                new LambdaQueryWrapper<AssetAuthInfo>() {{
                    eq(AssetAuthInfo::getAuthId, assetAuthInfoQueryReq.getAuthId());
                    eq(AssetAuthInfo::getIdType, assetAuthInfoQueryReq.getIdType());
                    eq(AssetAuthInfo::getAuthData, assetAuthInfoQueryReq.getAuthData());
                    eq(AssetAuthInfo::getAuthType, assetAuthInfoQueryReq.getAuthType());
                }}
        );
        if (delete>0) {
            return Result.success("删除成功");
        }else {
            return Result.success("删除失败");
        }

    }
}
