package com.muyu.data.source.service.impl;

import com.muyu.common.core.domain.Result;
import com.muyu.data.source.domain.DictionaryData;
import com.muyu.data.source.domain.DictionaryType;
import com.muyu.data.source.mapper.DictionaryMapper;
import com.muyu.data.source.service.DictionaryService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 字典业务实现层 DictionaryServiceImpl
 *
 * @author DeKangLiu
 * on 2024/4/29
 */
@Slf4j
@Service
public class DictionaryServiceImpl implements DictionaryService {
    @Autowired
    private DictionaryMapper dictionaryMapper;

    @Override
    public Result<List<DictionaryType>> findDictionaryByStructureId(Integer id) {

        List<DictionaryType> dictionaryTypeList = dictionaryMapper.selectDictionaryByStructureId(id);

        List<DictionaryType> list = dictionaryTypeList.stream()
                .map(dictionaryType -> {
                    List<DictionaryData> dictionaryDataList = dictionaryMapper.selectDictionaryDataByType(dictionaryType.getDictionaryType());
                    DictionaryType build = DictionaryType.builder()
                            .id(dictionaryType.getId())
                            .dictionaryDataList(dictionaryDataList)
                            .dictionaryType(dictionaryType.getDictionaryType())
                            .dictionaryName(dictionaryType.getDictionaryName())
                            .dictionaryDataList(dictionaryDataList)
                            .status(dictionaryType.getStatus())
                            .remark(dictionaryType.getRemark())
                            .createBy(dictionaryType.getCreateBy())
                            .createTime(dictionaryType.getCreateTime())
                            .updateBy(dictionaryType.getUpdateBy())
                            .updateTime(dictionaryType.getUpdateTime())
                            .build();
                    return build;
                }).toList();
        return Result.success(list);
    }

    @Override
    public Result addDictionaryType(DictionaryType dictionaryType) {
        return dictionaryMapper.addDictionaryType(dictionaryType) > 0 ? Result.success("上传成功") : Result.error("添加失败");
    }

    @Override
    public Result addDictionaryData(DictionaryData dictionaryData) {
        return dictionaryMapper.addDictionaryData(dictionaryData) > 0 ? Result.success("添加成功") : Result.error("添加失败");
    }

    @Override
    public Result deleteDictionaryData(Integer id) {
        return dictionaryMapper.deleteDictionaryData(id) > 0 ? Result.success("删除成功") : Result.error("删除失败");
    }

    @Override
    public Result updateDictionaryData(DictionaryData dictionaryData) {
        return dictionaryMapper.updateDictionaryData(dictionaryData) > 0 ? Result.success("修改成功") : Result.error("修改失败");
    }
}
